==> mongodb-7.0.28.gh.tar.gz: mongo-r7.0.28/src/mongo/db/query/stats/stats_cache_loader_mock.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/namespace_string.h"
#include "mongo/db/query/stats/collection_statistics.h"
#include "mongo/db/query/stats/stats_cache_loader.h"
#include "mongo/stdx/thread.h"

namespace mongo::stats {

class StatsCacheLoaderMock : public StatsCacheLoader {
public:
    SemiFuture<StatsCacheVal> getStats(OperationContext* opCtx,
                                       const StatsPathString& statsPath) override;

    void setStatsReturnValueForTest(StatusWith<StatsCacheVal> swStats);

    static const Status kInternalErrorStatus;

private:
    StatusWith<StatsCacheVal> _swStatsReturnValueForTest{kInternalErrorStatus};
};

}  // namespace mongo::stats

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/query/stats/stats_cache_loader_mock.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <boost/move/utility_core.hpp>

#include "mongo/base/status.h"
#include "mongo/base/status_with.h"
#include "mongo/db/namespace_string.h"
#include "mongo/db/operation_context.h"
#include "mongo/db/query/stats/collection_statistics.h"
#include "mongo/db/query/stats/stats_cache_loader.h"
#include "mongo/stdx/thread.h"
#include "mongo/util/future.h"

namespace mongo::stats {

class StatsCacheLoaderMock : public StatsCacheLoader {
public:
    SemiFuture<StatsCacheVal> getStats(OperationContext* opCtx,
                                       const StatsPathString& statsPath) override;

    void setStatsReturnValueForTest(StatusWith<StatsCacheVal> swStats) override;

    static const Status kInternalErrorStatus;

private:
    StatusWith<StatsCacheVal> _swStatsReturnValueForTest{kInternalErrorStatus};
};

}  // namespace mongo::stats
